To find the  average of a nxn matrix by separating it into a 2x2 matrix where n is even number
Line1-The order of the square matrix is supposed to be enter which should be an even number.
Line8-Enter the elements to be entered into your matrix. 